@@ -71,6 +71,13 @@ def parse(snt, merge_np= False):
 	'subtree': str([ list(t.subtree) for t in doc]),'children': str([ list(t.children) for t in doc]),
 	}) 
 
+def readline(infile, sepa=None):
+	with open(infile, 'r') as fp:
+		while True:
+			line = fp.readline()
+			if not line: break
+			yield line.strip().split(sepa) if sepa else line.strip()
+
 [ setattr(builtins, k, v) for k, v in globals().items() if not k.startswith("_") and not '.' in k and not hasattr(builtins,k) ]
 #setattr(builtins, "spacy", spacy)
 			
